class terminal:
    def __init__(self):
        self.display_list = {}
    def add(self,name,str):
        self.display_list[name] = str
    def delete(self,name):
        del self.display_list[name]
    def display(self):
        print("\033c")
        print("\033[H\033[2J",end="")
        keys = self.display_list.keys()
        for key in keys:
            print(self.display_list[key])

def hello():
    print("吵啥?")


from setuptools import setup, find_packages


setup(
    name="terminal_test",
    version="1.0.2",
    package=find_packages(),
    install_requires=[
        #test
    ],
    entry_points={
        "console_scripts":[
            "hello = terminal:hello"
        ]
    }
)